# SubmitDataQueryRequestOutputFormat

Specifies the format of the query results.  * `JSON` - Each row in the query results will be a JSON object. The format of the query result file is [JSON Lines](http://jsonlines.org/). * `CSV` - Each row in the query results will be a comma-separated list of values. * `TSV` - Each row in the query results will be a tab-separated list of values. * `DSV` - Pass any character as your custom delimiter into the `columnSeparator` field. 

## Enum

* `JSON` (value: `'JSON'`)

* `CSV` (value: `'CSV'`)

* `TSV` (value: `'TSV'`)

* `DSV` (value: `'DSV'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


